@@ -3,12 +3,14 @@
 # This file is part of gunicorn released under the MIT license.
 # See the NOTICE for more information.
 
+# Please remember to run "make -C docs html" after update "desc" attributes.
+
 import copy
 import grp
 import inspect
 try:
     import argparse
-except ImportError: # python 2.6
+except ImportError:  # python 2.6
     from . import argparse_compat as argparse
 import os
 import pwd
@@ -17,6 +19,7 @@ import sys
 import textwrap
 
 from gunicorn import __version__
+from gunicorn import _compat
 from gunicorn.errors import ConfigError
 from gunicorn import six
 from gunicorn import util
@@ -73,7 +76,7 @@ class Config(object):
         parser = argparse.ArgumentParser(**kwargs)
         parser.add_argument("-v", "--version",
                 action="version", default=argparse.SUPPRESS,
-                version="%(prog)s (version " +  __version__ + ")\n",
+                version="%(prog)s (version " + __version__ + ")\n",
                 help="show program's version number and exit")
         parser.add_argument("args", nargs="*", help=argparse.SUPPRESS)
 
@@ -118,7 +121,7 @@ class Config(object):
     @property
     def address(self):
         s = self.settings['bind'].get()
-        return [util.parse_address(six.bytes_to_str(bind)) for bind in s]
+        return [util.parse_address(_compat.bytes_to_str(bind)) for bind in s]
 
     @property
     def uid(self):
@@ -141,11 +144,18 @@ class Config(object):
         uri = self.settings['logger_class'].get()
         if uri == "simple":
             # support the default
-            uri = "gunicorn.glogging.Logger"
+            uri = LoggerClass.default
 
-        logger_class = util.load_class(uri,
-                default="gunicorn.glogging.Logger",
-                section="gunicorn.loggers")
+        # if default logger is in use, and statsd is on, automagically switch
+        # to the statsd logger
+        if uri == LoggerClass.default:
+            if 'statsd_host' in self.settings and self.settings['statsd_host'].value is not None:
+                uri = "gunicorn.instrument.statsd.Statsd"
+
+        logger_class = util.load_class(
+            uri,
+            default="gunicorn.glogging.Logger",
+            section="gunicorn.loggers")
 
         if hasattr(logger_class, "install"):
             logger_class.install()
@@ -159,7 +169,7 @@ class Config(object):
     def ssl_options(self):
         opts = {}
         for name, value in self.settings.items():
-            if value.section == 'Ssl':
+            if value.section == 'SSL':
                 opts[name] = value.get()
         return opts
 
@@ -172,7 +182,7 @@ class Config(object):
             return env
 
         for e in raw_env:
-            s = six.bytes_to_str(e)
+            s = _compat.bytes_to_str(e)
             try:
                 k, v = s.split('=', 1)
             except ValueError:
@@ -182,6 +192,17 @@ class Config(object):
 
         return env
 
+    @property
+    def sendfile(self):
+        if self.settings['sendfile'].get() is not None:
+            return False
+
+        if 'SENDFILE' in os.environ:
+            sendfile = os.environ['SENDFILE'].lower()
+            return sendfile in ['y', '1', 'yes', 'true']
+
+        return True
+
 
 class SettingMeta(type):
     def __new__(cls, name, bases, attrs):
@@ -219,8 +240,6 @@ class Setting(object):
     nargs = None
     const = None
 
-
-
     def __init__(self):
         if self.default is not None:
             self.set(self.default)
@@ -262,7 +281,8 @@ class Setting(object):
         return self.value
 
     def set(self, val):
-        assert six.callable(self.validator), "Invalid validator: %s" % self.name
+        if not six.callable(self.validator):
+            raise TypeError('Invalid validator: %s' % self.name)
         self.value = self.validator(val)
 
     def __lt__(self, other):
@@ -274,6 +294,9 @@ Setting = SettingMeta('Setting', (Setting,), {})
 
 
 def validate_bool(val):
+    if val is None:
+        return
+
     if isinstance(val, bool):
         return val
     if not isinstance(val, six.string_types):
@@ -427,7 +450,7 @@ def validate_file(val):
     # valid if the value is a string
     val = validate_string(val)
 
-     # transform relative paths
+    # transform relative paths
     path = os.path.abspath(os.path.normpath(os.path.join(util.getcwd(), val)))
 
     # test if the path exists
@@ -436,6 +459,15 @@ def validate_file(val):
 
     return path
 
+def validate_hostport(val):
+    val = validate_string(val)
+    if val is None:
+        return None
+    elements = val.split(":")
+    if len(elements) == 2:
+        return (elements[0], int(elements[1]))
+    else:
+        raise TypeError("Value must consist of: hostname:port")
 
 def get_default_config_file():
     config_path = os.path.join(os.path.abspath(os.getcwd()),
@@ -445,19 +477,24 @@ def get_default_config_file():
     return None
 
 
-# Please remember to run "make html" in docs/ after update "desc" attributes.
 class ConfigFile(Setting):
     name = "config"
     section = "Config File"
     cli = ["-c", "--config"]
-    meta = "FILE"
+    meta = "CONFIG"
     validator = validate_string
     default = None
     desc = """\
-        The path to a Gunicorn config file.
+        The Gunicorn config file.
+
+        A string of the form ``PATH``, ``file:PATH``, or ``python:MODULE_NAME``.
 
         Only has an effect when specified on the command line or as part of an
         application specific configuration.
+
+        .. versionchanged:: 19.4
+           Loading the config from a Python module requires the ``python:``
+           prefix.
         """
 
 class Bind(Setting):
@@ -476,8 +513,8 @@ class Bind(Setting):
     desc = """\
         The socket to bind.
 
-        A string of the form: 'HOST', 'HOST:PORT', 'unix:PATH'. An IP is a valid
-        HOST.
+        A string of the form: ``HOST``, ``HOST:PORT``, ``unix:PATH``. An IP is
+        a valid ``HOST``.
 
         Multiple addresses can be bound. ex.::
 
@@ -515,16 +552,16 @@ class Workers(Setting):
     meta = "INT"
     validator = validate_pos_int
     type = int
-    default = int(os.environ.get('WEB_CONCURRENCY', 1))
+    default = int(os.environ.get("WEB_CONCURRENCY", 1))
     desc = """\
-        The number of worker process for handling requests.
+        The number of worker processes for handling requests.
 
-        A positive integer generally in the 2-4 x $(NUM_CORES) range. You'll
-        want to vary this a bit to find the best for your particular
+        A positive integer generally in the ``2-4 x $(NUM_CORES)`` range.
+        You'll want to vary this a bit to find the best for your particular
         application's work load.
 
-        By default, the value of the WEB_CONCURRENCY environment variable. If
-        it is not defined, the default is 1.
+        By default, the value of the ``WEB_CONCURRENCY`` environment variable.
+        If it is not defined, the default is ``1``.
         """
 
 
@@ -538,11 +575,9 @@ class WorkerClass(Setting):
     desc = """\
         The type of workers to use.
 
-        The default class (sync) should handle most 'normal' types of
-        workloads.  You'll want to read
-        http://docs.gunicorn.org/en/latest/design.html for information
-        on when you might want to choose one of the other worker
-        classes.
+        The default class (``sync``) should handle most "normal" types of
+        workloads. You'll want to read :doc:`design` for information on when
+        you might want to choose one of the other worker classes.
 
         A string referring to one of the following bundled classes:
 
@@ -550,12 +585,14 @@ class WorkerClass(Setting):
         * ``eventlet`` - Requires eventlet >= 0.9.7
         * ``gevent``   - Requires gevent >= 0.13
         * ``tornado``  - Requires tornado >= 0.2
+        * ``gthread``  - Python 2 requires the futures package to be installed
+        * ``gaiohttp`` - Requires Python 3.4 and aiohttp >= 0.21.5
 
-        Optionally, you can provide your own worker by giving gunicorn a
-        python path to a subclass of gunicorn.workers.base.Worker. This
-        alternative syntax will load the gevent class:
-        ``gunicorn.workers.ggevent.GeventWorker``. Alternatively the syntax
-        can also load the gevent class with ``egg:gunicorn#gevent``
+        Optionally, you can provide your own worker by giving Gunicorn a
+        Python path to a subclass of ``gunicorn.workers.base.Worker``.
+        This alternative syntax will load the gevent class:
+        ``gunicorn.workers.ggevent.GeventWorker``. Alternatively, the syntax
+        can also load the gevent class with ``egg:gunicorn#gevent``.
         """
 
 class WorkerThreads(Setting):
@@ -571,8 +608,8 @@ class WorkerThreads(Setting):
 
         Run each worker with the specified number of threads.
 
-        A positive integer generally in the 2-4 x $(NUM_CORES) range. You'll
-        want to vary this a bit to find the best for your particular
+        A positive integer generally in the ``2-4 x $(NUM_CORES)`` range.
+        You'll want to vary this a bit to find the best for your particular
         application's work load.
 
         If it is not defined, the default is 1.
@@ -614,6 +651,25 @@ class MaxRequests(Setting):
         """
 
 
+class MaxRequestsJitter(Setting):
+    name = "max_requests_jitter"
+    section = "Worker Processes"
+    cli = ["--max-requests-jitter"]
+    meta = "INT"
+    validator = validate_pos_int
+    type = int
+    default = 0
+    desc = """\
+        The maximum jitter to add to the *max_requests* setting.
+
+        The jitter causes the restart per worker to be randomized by
+        ``randint(0, max_requests_jitter)``. This is intended to stagger worker
+        restarts to avoid all workers restarting at the same time.
+
+        .. versionadded:: 19.2
+        """
+
+
 class Timeout(Setting):
     name = "timeout"
     section = "Worker Processes"
@@ -643,9 +699,9 @@ class GracefulTimeout(Setting):
     desc = """\
         Timeout for graceful workers restart.
 
-        Generally set to thirty seconds. How max time worker can handle
-        request after got restart signal. If the time is up worker will
-        be force killed.
+        After receiving a restart signal, workers have this much time to finish
+        serving requests. Workers still alive after the timeout (starting from
+        the receipt of the restart signal) are force killed.
         """
 
 
@@ -700,7 +756,7 @@ class LimitRequestFields(Setting):
         Limit the number of HTTP headers fields in a request.
 
         This parameter is used to limit the number of headers in a request to
-        prevent DDOS attack. Used with the `limit_request_field_size` it allows
+        prevent DDOS attack. Used with the *limit_request_field_size* it allows
         more safety. By default this value is 100 and can't be larger than
         32768.
         """
@@ -722,21 +778,6 @@ class LimitRequestFieldSize(Setting):
         """
 
 
-class Debug(Setting):
-    name = "debug"
-    section = "Debugging"
-    cli = ["--debug"]
-    validator = validate_bool
-    action = "store_true"
-    default = False
-    desc = """\
-        Turn on debugging in the server.
-
-        **DEPRECATED**: This no functionality was removed after v18.0.
-        This option is now a no-op.
-        """
-
-
 class Reload(Setting):
     name = "reload"
     section = 'Debugging'
@@ -778,7 +819,7 @@ class ConfigCheck(Setting):
     action = "store_true"
     default = False
     desc = """\
-        Check the configuration..
+        Check the configuration.
         """
 
 
@@ -799,6 +840,29 @@ class PreloadApp(Setting):
         """
 
 
+class Sendfile(Setting):
+    name = "sendfile"
+    section = "Server Mechanics"
+    cli = ["--no-sendfile"]
+    validator = validate_bool
+    action = "store_const"
+    const = False
+
+    desc = """\
+        Disables the use of ``sendfile()``.
+
+        If not set, the value of the ``SENDFILE`` environment variable is used
+        to enable or disable its usage.
+
+        .. versionadded:: 19.2
+        .. versionchanged:: 19.4
+           Swapped ``--sendfile`` with ``--no-sendfile`` to actually allow
+           disabling.
+        .. versionchanged:: 19.6
+           added support for the ``SENDFILE`` environment variable
+        """
+
+
 class Chdir(Setting):
     name = "chdir"
     section = "Server Mechanics"
@@ -870,6 +934,7 @@ class WorkerTmpDir(Setting):
         If not set, the default temporary directory will be used.
         """
 
+
 class User(Setting):
     name = "user"
     section = "Server Mechanics"
@@ -881,8 +946,8 @@ class User(Setting):
         Switch worker processes to run as this user.
 
         A valid user id (as an integer) or the name of a user that can be
-        retrieved with a call to pwd.getpwnam(value) or None to not change
-        the worker process user.
+        retrieved with a call to ``pwd.getpwnam(value)`` or ``None`` to not
+        change the worker process user.
         """
 
 
@@ -897,8 +962,8 @@ class Group(Setting):
         Switch worker process to run as this group.
 
         A valid group id (as an integer) or the name of a user that can be
-        retrieved with a call to pwd.getgrnam(value) or None to not change
-        the worker processes group.
+        retrieved with a call to ``pwd.getgrnam(value)`` or ``None`` to not
+        change the worker processes group.
         """
 
 
@@ -915,9 +980,10 @@ class Umask(Setting):
 
         Note that this affects unix socket permissions.
 
-        A valid value for the os.umask(mode) call or a string compatible with
-        int(value, 0) (0 means Python guesses the base, so values like "0",
-        "0xFF", "0022" are valid for decimal, hex, and octal representations)
+        A valid value for the ``os.umask(mode)`` call or a string compatible
+        with ``int(value, 0)`` (``0`` means Python guesses the base, so values
+        like ``0``, ``0xFF``, ``0022`` are valid for decimal, hex, and octal
+        representations)
         """
 
 
@@ -950,8 +1016,8 @@ class SecureSchemeHeader(Setting):
     desc = """\
 
         A dictionary containing headers and values that the front-end proxy
-        uses to indicate HTTPS requests. These tell gunicorn to set
-        wsgi.url_scheme to "https", so your application can tell that the
+        uses to indicate HTTPS requests. These tell Gunicorn to set
+        ``wsgi.url_scheme`` to ``https``, so your application can tell that the
         request is secure.
 
         The dictionary should map upper-case header names to exact string
@@ -970,14 +1036,17 @@ class ForwardedAllowIPS(Setting):
     cli = ["--forwarded-allow-ips"]
     meta = "STRING"
     validator = validate_string_to_list
-    default = "127.0.0.1"
+    default = os.environ.get("FORWARDED_ALLOW_IPS", "127.0.0.1")
     desc = """\
         Front-end's IPs from which allowed to handle set secure headers.
         (comma separate).
 
-        Set to "*" to disable checking of Front-end IPs (useful for setups
+        Set to ``*`` to disable checking of Front-end IPs (useful for setups
         where you don't know in advance the IP address of Front-end, but
-        you still trust the environment)
+        you still trust the environment).
+
+        By default, the value of the ``FORWARDED_ALLOW_IPS`` environment
+        variable. If it is not defined, the default is ``"127.0.0.1"``.
         """
 
 
@@ -991,7 +1060,7 @@ class AccessLog(Setting):
     desc = """\
         The Access log file to write to.
 
-        "-" means log to stderr.
+        ``'-'`` means log to stderr.
         """
 
 
@@ -1009,12 +1078,17 @@ class AccessLogFormat(Setting):
         Identifier  Description
         ==========  ===========
         h           remote address
-        l           '-'
-        u           currently '-', may be user name in future releases
+        l           ``'-'``
+        u           user name
         t           date of the request
         r           status line (e.g. ``GET / HTTP/1.1``)
+        m           request method
+        U           URL path without query string
+        q           query string
+        H           protocol
         s           status
-        b           response length or '-'
+        B           response length
+        b           response length or ``'-'`` (CLF format)
         f           referer
         a           user agent
         T           request time in seconds
@@ -1033,11 +1107,15 @@ class ErrorLog(Setting):
     cli = ["--error-logfile", "--log-file"]
     meta = "FILE"
     validator = validate_string
-    default = None
+    default = '-'
     desc = """\
         The Error log file to write to.
 
-        "-" means log to stderr.
+        Using ``'-'`` for FILE makes gunicorn log to stderr.
+
+        .. versionchanged:: 19.2
+           Log to stderr by default.
+
         """
 
 
@@ -1061,6 +1139,20 @@ class Loglevel(Setting):
         """
 
 
+class CaptureOutput(Setting):
+    name = "capture_output"
+    section = "Logging"
+    cli = ["--capture-output"]
+    validator = validate_bool
+    action = 'store_true'
+    default = False
+    desc = """\
+        Redirect stdout/stderr to Error log.
+
+        .. versionadded:: 19.6
+        """
+
+
 class LoggerClass(Setting):
     name = "logger_class"
     section = "Logging"
@@ -1069,15 +1161,15 @@ class LoggerClass(Setting):
     validator = validate_class
     default = "gunicorn.glogging.Logger"
     desc = """\
-        The logger you want to use to log events in gunicorn.
+        The logger you want to use to log events in Gunicorn.
 
         The default class (``gunicorn.glogging.Logger``) handle most of
         normal usages in logging. It provides error and access logging.
 
-        You can provide your own worker by giving gunicorn a
-        python path to a subclass like gunicorn.glogging.Logger.
+        You can provide your own worker by giving Gunicorn a
+        Python path to a subclass like ``gunicorn.glogging.Logger``.
         Alternatively the syntax can also load the Logger class
-        with `egg:gunicorn#simple`
+        with ``egg:gunicorn#simple``.
         """
 
 
@@ -1116,11 +1208,11 @@ class SyslogTo(Setting):
 
     Address is a string of the form:
 
-    * 'unix://PATH#TYPE' : for unix domain socket. TYPE can be 'stream'
-      for the stream driver or 'dgram' for the dgram driver.
-      'stream' is the default.
-    * 'udp://HOST:PORT' : for UDP sockets
-    * 'tcp://HOST:PORT' : for TCP sockets
+    * ``unix://PATH#TYPE`` : for unix domain socket. ``TYPE`` can be ``stream``
+      for the stream driver or ``dgram`` for the dgram driver.
+      ``stream`` is the default.
+    * ``udp://HOST:PORT`` : for UDP sockets
+    * ``tcp://HOST:PORT`` : for TCP sockets
 
     """
 
@@ -1145,10 +1237,10 @@ class SyslogPrefix(Setting):
     validator = validate_string
     default = None
     desc = """\
-    makes gunicorn use the parameter as program-name in the syslog entries.
+    Makes Gunicorn use the parameter as program-name in the syslog entries.
 
-    All entries will be prefixed by gunicorn.<prefix>. By default the program
-    name is the name of the process.
+    All entries will be prefixed by ``gunicorn.<prefix>``. By default the
+    program name is the name of the process.
     """
 
 
@@ -1172,15 +1264,44 @@ class EnableStdioInheritance(Setting):
     default = False
     action = "store_true"
     desc = """\
-    Enable stdio inheritance
+    Enable stdio inheritance.
 
     Enable inheritance for stdio file descriptors in daemon mode.
 
-    Note: To disable the python stdout buffering, you can to set the user
+    Note: To disable the Python stdout buffering, you can to set the user
     environment variable ``PYTHONUNBUFFERED`` .
     """
 
 
+# statsD monitoring
+class StatsdHost(Setting):
+    name = "statsd_host"
+    section = "Logging"
+    cli = ["--statsd-host"]
+    meta = "STATSD_ADDR"
+    default = None
+    validator = validate_hostport
+    desc = """\
+    ``host:port`` of the statsd server to log to.
+
+    .. versionadded:: 19.1
+    """
+
+class StatsdPrefix(Setting):
+    name = "statsd_prefix"
+    section = "Logging"
+    cli = ["--statsd-prefix"]
+    meta = "STATSD_PREFIX"
+    default = ""
+    validator = validate_string
+    desc = """\
+    Prefix to use when emitting statsd metrics (a trailing ``.`` is added,
+    if not provided).
+
+    .. versionadded:: 19.2
+    """
+
+
 class Procname(Setting):
     name = "proc_name"
     section = "Process Naming"
@@ -1196,7 +1317,7 @@ class Procname(Setting):
         name to tell them apart. This requires that you install the setproctitle
         module.
 
-        It defaults to 'gunicorn'.
+        If not set, the *default_proc_name* setting will be used.
         """
 
 
@@ -1220,10 +1341,10 @@ class DjangoSettings(Setting):
     desc = """\
         The Python path to a Django settings module. (deprecated)
 
-        e.g. 'myproject.settings.main'. If this isn't provided, the
-        DJANGO_SETTINGS_MODULE environment variable will be used.
+        e.g. ``myproject.settings.main``. If this isn't provided, the
+        ``DJANGO_SETTINGS_MODULE`` environment variable will be used.
 
-        **DEPRECATED**: use the --env argument instead.
+        **DEPRECATED**: use the ``--env`` argument instead.
         """
 
 
@@ -1235,10 +1356,10 @@ class PythonPath(Setting):
     validator = validate_string
     default = None
     desc = """\
-        A directory to add to the Python path.
+        A comma-separated list of directories to add to the Python path.
 
         e.g.
-        '/home/djangoprojects/myproject'.
+        ``'/home/djangoprojects/myproject,/home/python/mylibrary'``.
         """
 
 
@@ -1250,9 +1371,9 @@ class Paste(Setting):
     validator = validate_string
     default = None
     desc = """\
-        Load a paste.deploy config file. The argument may contain a "#" symbol
-        followed by the name of an app section from the config file, e.g.
-        "production.ini#admin".
+        Load a PasteDeploy config file. The argument may contain a ``#``
+        symbol followed by the name of an app section from the config file,
+        e.g. ``production.ini#admin``.
 
         At this time, using alternate server blocks is not supported. Use the
         command line arguments to control server configuration instead.
@@ -1369,7 +1490,7 @@ class WorkerInt(Setting):
 
     default = staticmethod(worker_int)
     desc = """\
-        Called just after a worker exited on SIGINT or SIGTERM.
+        Called just after a worker exited on SIGINT or SIGQUIT.
 
         The callable needs to accept one instance variable for the initialized
         Worker.
@@ -1389,7 +1510,7 @@ class WorkerAbort(Setting):
     desc = """\
         Called when a worker received the SIGABRT signal.
 
-        This call generally happen on timeout.
+        This call generally happens on timeout.
 
         The callable needs to accept one instance variable for the initialized
         Worker.
@@ -1473,13 +1594,13 @@ class NumWorkersChanged(Setting):
         pass
     default = staticmethod(nworkers_changed)
     desc = """\
-        Called just after num_workers has been changed.
+        Called just after *num_workers* has been changed.
 
         The callable needs to accept an instance variable of the Arbiter and
         two integers of number of workers after and before change.
 
-        If the number of workers is set for the first time, old_value would be
-        None.
+        If the number of workers is set for the first time, *old_value* would
+        be ``None``.
         """
 
 class OnExit(Setting):
@@ -1492,7 +1613,7 @@ class OnExit(Setting):
 
     default = staticmethod(on_exit)
     desc = """\
-        Called just before exiting gunicorn.
+        Called just before exiting Gunicorn.
 
         The callable needs to accept a single instance variable for the Arbiter.
         """
@@ -1508,8 +1629,8 @@ class ProxyProtocol(Setting):
     desc = """\
         Enable detect PROXY protocol (PROXY mode).
 
-        Allow using Http and Proxy together. It's may be useful for work with
-        stunnel as https frondend and gunicorn as http server.
+        Allow using HTTP and Proxy together. It may be useful for work with
+        stunnel as HTTPS frontend and Gunicorn as HTTP server.
 
         PROXY protocol: http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt
 
@@ -1533,7 +1654,7 @@ class ProxyAllowFrom(Setting):
     desc = """\
         Front-end's IPs from which allowed accept proxy requests (comma separate).
 
-        Set to "*" to disable checking of Front-end IPs (useful for setups
+        Set to ``*`` to disable checking of Front-end IPs (useful for setups
         where you don't know in advance the IP address of Front-end, but
         you still trust the environment)
         """
@@ -1541,7 +1662,7 @@ class ProxyAllowFrom(Setting):
 
 class KeyFile(Setting):
     name = "keyfile"
-    section = "Ssl"
+    section = "SSL"
     cli = ["--keyfile"]
     meta = "FILE"
     validator = validate_string
@@ -1553,7 +1674,7 @@ class KeyFile(Setting):
 
 class CertFile(Setting):
     name = "certfile"
-    section = "Ssl"
+    section = "SSL"
     cli = ["--certfile"]
     meta = "FILE"
     validator = validate_string
@@ -1564,7 +1685,7 @@ class CertFile(Setting):
 
 class SSLVersion(Setting):
     name = "ssl_version"
-    section = "Ssl"
+    section = "SSL"
     cli = ["--ssl-version"]
     validator = validate_pos_int
     default = ssl.PROTOCOL_TLSv1
@@ -1574,7 +1695,7 @@ class SSLVersion(Setting):
 
 class CertReqs(Setting):
     name = "cert_reqs"
-    section = "Ssl"
+    section = "SSL"
     cli = ["--cert-reqs"]
     validator = validate_pos_int
     default = ssl.CERT_NONE
@@ -1584,7 +1705,7 @@ class CertReqs(Setting):
 
 class CACerts(Setting):
     name = "ca_certs"
-    section = "Ssl"
+    section = "SSL"
     cli = ["--ca-certs"]
     meta = "FILE"
     validator = validate_string
@@ -1595,7 +1716,7 @@ class CACerts(Setting):
 
 class SuppressRaggedEOFs(Setting):
     name = "suppress_ragged_eofs"
-    section = "Ssl"
+    section = "SSL"
     cli = ["--suppress-ragged-eofs"]
     action = "store_true"
     default = True
@@ -1606,7 +1727,7 @@ class SuppressRaggedEOFs(Setting):
 
 class DoHandshakeOnConnect(Setting):
     name = "do_handshake_on_connect"
-    section = "Ssl"
+    section = "SSL"
     cli = ["--do-handshake-on-connect"]
     validator = validate_bool
     action = "store_true"
@@ -1615,10 +1736,11 @@ class DoHandshakeOnConnect(Setting):
     Whether to perform SSL handshake on socket connect (see stdlib ssl module's)
     """
 
+
 if sys.version_info >= (2, 7):
     class Ciphers(Setting):
         name = "ciphers"
-        section = "Ssl"
+        section = "SSL"
         cli = ["--ciphers"]
         validator = validate_string
         default = 'TLSv1'
