@@ -4,15 +4,23 @@
 # See the NOTICE for more information.
 
 import os
+import platform
 import tempfile
 
 from gunicorn import util
 
+PLATFORM = platform.system()
+IS_CYGWIN = PLATFORM.startswith('CYGWIN')
+
+
 class WorkerTmp(object):
 
     def __init__(self, cfg):
         old_umask = os.umask(cfg.umask)
-        fd, name = tempfile.mkstemp(prefix="wgunicorn-")
+        fdir = cfg.worker_tmp_dir
+        if fdir and not os.path.isdir(fdir):
+            raise RuntimeError("%s doesn't exist. Can't create workertmp." % fdir)
+        fd, name = tempfile.mkstemp(prefix="wgunicorn-", dir=fdir)
 
         # allows the process to write to the file
         util.chown(name, cfg.uid, cfg.gid)
@@ -20,7 +28,8 @@ class WorkerTmp(object):
 
         # unlink the file so we don't leak tempory files
         try:
-            os.unlink(name)
+            if not IS_CYGWIN:
+                util.unlink(name)
             self._tmp = os.fdopen(fd, 'w+b', 1)
         except:
             os.close(fd)
@@ -30,12 +39,12 @@ class WorkerTmp(object):
 
     def notify(self):
         try:
-            self.spinner = (self.spinner+1) % 2
+            self.spinner = (self.spinner + 1) % 2
             os.fchmod(self._tmp.fileno(), self.spinner)
         except AttributeError:
             # python < 2.6
             self._tmp.truncate(0)
-            os.write(self._tmp.fileno(), "X")
+            os.write(self._tmp.fileno(), b"X")
 
     def last_update(self):
         return os.fstat(self._tmp.fileno()).st_ctime
